==> opennms_21.0.3-1.tar.gz: opennms-source/core/jmx/api/src/main/java/org/opennms/netmgt/jmx/JmxSampleProcessor.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.jmx;

import org.opennms.netmgt.jmx.samples.JmxAttributeSample;
import org.opennms.netmgt.jmx.samples.JmxCompositeSample;

/**
 * Processes collected JMX Samples.
 */
public interface JmxSampleProcessor {
    /**
     * Callback method for each collected MBean Attribute.
     *
     * @param attributeSample The collected sample.
     */
    void process(JmxAttributeSample attributeSample);

    /**
     * Callback method for each collected Composite Member.
     *
     * @param compositeSample The collected sample.
     */
    void process(JmxCompositeSample compositeSample);
}

==> opennms_23.0.2-1.tar.gz: opennms-source/core/jmx/api/src/main/java/org/opennms/netmgt/jmx/JmxSampleProcessor.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.jmx;

import javax.management.ObjectName;

import org.opennms.netmgt.jmx.samples.JmxAttributeSample;
import org.opennms.netmgt.jmx.samples.JmxCompositeSample;

/**
 * Processes collected JMX Samples.
 */
public interface JmxSampleProcessor {
    /**
     * Callback method for each collected MBean Attribute.
     *
     * @param attributeSample The collected sample.
     */
    void process(JmxAttributeSample attributeSample, ObjectName objectName);

    /**
     * Callback method for each collected Composite Member.
     *
     * @param compositeSample The collected sample.
     */
    void process(JmxCompositeSample compositeSample, ObjectName objectName);
}
